"""
arrayexpress_get_experiment

Get detailed information about a specific ArrayExpress experiment by its accession ID (E-GEOD, E-...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def arrayexpress_get_experiment(
    experiment_id: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get detailed information about a specific ArrayExpress experiment by its accession ID (E-GEOD, E-...

    Parameters
    ----------
    experiment_id : str
        ArrayExpress experiment ID (e.g., 'E-MTAB-1234')
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {k: v for k, v in {"experiment_id": experiment_id}.items() if v is not None}
    return get_shared_client().run_one_function(
        {
            "name": "arrayexpress_get_experiment",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["arrayexpress_get_experiment"]
